************
WebsocketRPC
************

.. note:: This is a low level class that can be used in combination with
          GrapheneClient

This class allows to call API methods exposed by the witness node via
websockets. It does **not** support notifications and is not run
asynchronously.

.. autoclass:: beemgrapheneapi.graphenewsrpc.GrapheneWebsocketRPC
     :members:
